Crate iyes_loopless

Crate iyes_loopless 

Composable Alternatives to Bevy’s RunCriteria, States, FixedTimestep

This crate offers alternatives to the Run Criteria, States, and FixedTimestep scheduling features currently offered by the Bevy game engine.

The ones provided by this crate do not use “looping stages”, and can therefore be combined/composed together elegantly, solving some of the most annoying usability limitations of the respective APIs in Bevy.

Modules

condition
Conditional systems supporting multiple run conditions
fixedtimestep
Fixed Timestep implementation as a Bevy Stage
prelude
Prelude: convenient import for all the user-facing APIs provided by the crate
state
States implementation based on Run Conditions and a transitions Stage