FixedTimesteps

Struct FixedTimesteps 

pub struct FixedTimesteps { /* private fields */ }
Resource type that allows you to get info about and to manipulate fixed timestep state

If you want to access parameters of your fixed timestep(s), such as the timestep duration, accumulator, and paused state, you can get them from this resource. They are contained in a FixedTimestepInfo struct, which you can get using the various methods on this type.

If you mutate the timestep duration or paused state, they will be taken into account from the next run of that fixed timestep.

From within a fixed timestep system, you can also mutate the accumulator. May be useful for networking or other use cases that need to stretch time.

Implementations

Source

impl FixedTimesteps

pub fn get(&self, label: TimestepName) -> Option<&FixedTimestepInfo>

Returns a reference to the timestep info for a given timestep by name.

pub fn get_current(&self) -> Option<&FixedTimestepInfo>

Returns a reference to the timestep info for the currently running stage.

Returns Some only if called inside a fixed timestep stage.

pub fn current(&self) -> &FixedTimestepInfo

Panicking version of [get_current]

pub fn get_single(&self) -> Option<&FixedTimestepInfo>

Returns a reference to the timestep info, assuming you only have one.

pub fn single(&self) -> &FixedTimestepInfo

Panicking version of [get_single]

pub fn get_mut(&mut self, label: TimestepName) -> Option<&mut FixedTimestepInfo>

Returns a mut reference to the timestep info for a given timestep by name.

pub fn get_current_mut(&mut self) -> Option<&mut FixedTimestepInfo>

Returns a mut reference to the timestep info for the currently running stage.

Returns Some only if called inside a fixed timestep stage.

pub fn current_mut(&mut self) -> &mut FixedTimestepInfo

Panicking version of [get_current_mut]

pub fn get_single_mut(&mut self) -> Option<&mut FixedTimestepInfo>

Returns a mut reference to the timestep info, assuming you only have one.

pub fn single_mut(&mut self) -> &mut FixedTimestepInfo

Panicking version of [get_single_mut]