pub trait ConditionHelpers: Sized {
Show 13 methods fn run_if<Condition, Params>(self, condition: Condition) -> Self
    where
        Condition: IntoSystem<(), bool, Params>
; fn run_if_not<Condition, Params>(self, condition: Condition) -> Self
    where
        Condition: IntoSystem<(), bool, Params>
, { ... } fn run_on_event<T: Send + Sync + 'static>(self) -> Self { ... } fn run_if_resource_exists<T: Resource>(self) -> Self { ... } fn run_unless_resource_exists<T: Resource>(self) -> Self { ... } fn run_if_resource_added<T: Resource>(self) -> Self { ... } fn run_if_resource_removed<T: Resource>(self) -> Self { ... } fn run_if_resource_equals<T: Resource + PartialEq>(self, value: T) -> Self { ... } fn run_unless_resource_equals<T: Resource + PartialEq>(
        self,
        value: T
    ) -> Self { ... } fn run_in_state<T: StateData>(self, state: T) -> Self { ... } fn run_not_in_state<T: StateData>(self, state: T) -> Self { ... } fn run_in_bevy_state<T: StateData>(self, state: T) -> Self { ... } fn run_not_in_bevy_state<T: StateData>(self, state: T) -> Self { ... }
}

Required Methods

Provided Methods

Helper: add a condition, but flip its result

Helper: add a condition to run if there are events of the given type

Helper: add a condition to run if a resource of a given type exists

Helper: add a condition to run if a resource of a given type does not exist

Helper: add a condition to run if a resource was added

Helper: add a condition to run if a resource was removed

Helper: add a condition to run if a resource equals the given value

Helper: add a condition to run if a resource does not equal the given value

Helper: run in a specific state (checks the CurrentState resource)

Helper: run when not in a specific state (checks the CurrentState resource)

Helper: run in a specific Bevy state (checks the State<T> resource)

Helper: run when not in a specific Bevy state (checks the State<T> resource)

Implementors